@@ -4,6 +4,9 @@ from json_resource.instance import JSONInstance
 
 
 class Array(JSONInstance, list):
+    """ Array resource. This is a subclass of `list` that can be validated using
+    a schema.
+    """
     type = (list, tuple)
 
     def __init__(self, data=None, schema=None):
