@@ -22,4 +22,10 @@ class ResourceExists(Exception):
     pass
 
 
+class Forbidden(Exception):
+    pass
+
+
+class UnAuthorized(Exception):
+    pass
 
