@@ -5,6 +5,9 @@ from json_pointer import Pointer
 
 
 class Object(JSONInstance, dict):
+    """ Object resource. This is a subclass of `dict` that can be validated using
+    a schema.
+    """
     type = (dict, )
 
     def __init__(self, data=None, schema=None):
@@ -15,6 +18,11 @@ class Object(JSONInstance, dict):
         dict.__init__(self, data)
 
     def __getitem__(self, key):
+        """ Override __getitem__ so that it accepts json pointers.
+
+        When a subschema is available, the returned object is a resource that
+        also has a schema.
+        """
         if isinstance(key, Pointer):
             return key.get(self)
         else:
@@ -27,6 +35,11 @@ class Object(JSONInstance, dict):
             return result
 
     def get(self, key, default=None):
+        """ Override `get` to accept json pointers.
+
+        When a subschema is available, the returned object is a resource that
+        also has a schema.
+        """
         try:
             if isinstance(key, Pointer):
                 return key.get(self, default)
@@ -45,6 +58,7 @@ class Object(JSONInstance, dict):
                 key, value in dict.items(self)]
 
     def _sub_schema(self, key):
+        """Returns the schema of the item under `key`."""
         try:
             return self.schema.sub_schema(self, key)
         except AttributeError:
